Subject: [bug#67473] [PATCH gnome-team v7 10/15] gnu: libsoup-minimal: Update style.

From: Vivien Kraus <[email-masked]>
Date: Sat, 2 Dec 2023 16:09:40 +0100

* gnu/packages/gnome.scm (libsoup-minimal) [arguments]: Convert to list of
G-Expressions.
* gnu/packages/gnome.scm (libsoup-minimal-2) [arguments]: Convert to list of G-Expressions.

Change-Id: I72ebe6614eac3ee032057ffeb76dff5d8d821a8e
---
 gnu/packages/gnome.scm | 53 +++++++++++++++++++++---------------------
 1 file changed, 27 insertions(+), 26 deletions(-)

diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index dd3d92ae2d..507ee78690 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -5031,25 +5031,26 @@ (define-public libsoup-minimal
                 "1an5n2sa70f40my4g20lk38s5ib99c32bzzg8gm91v9nbxr6f719"))))
     (build-system meson-build-system)
     (arguments
-     `(#:configure-flags '("-Ddocs=disabled")
-       #:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'adjust-tests
-           (lambda _
-             ;; This test fails due to missing /etc/nsswitch.conf
-             ;; in the build environment.
-             (substitute* "tests/unix-socket-test.c"
-               ((".*/sockets/unconnected.*") ""))
-
-             ;; These fail because "subdomain.localhost" does not resolve in
-             ;; the build environment.  Moreover, the hsts-test suite fails on
-             ;; i686-linux because of errors from `session_get_uri' like
-             ;; "Unexpected status 200 OK (expected 301 Moved Permanently)"
-             ;; (see: https://gitlab.gnome.org/GNOME/libsoup/-/issues/239).
-             (substitute* "tests/meson.build"
-               ((".*'name': 'hsts'.*") ""))
-             (substitute* "tests/hsts-db-test.c"
-               ((".*/hsts-db/subdomains.*") "")))))))
+     (list
+      #:configure-flags #~(list "-Ddocs=disabled")
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'adjust-tests
+            (lambda _
+              ;; This test fails due to missing /etc/nsswitch.conf
+              ;; in the build environment.
+              (substitute* "tests/unix-socket-test.c"
+                ((".*/sockets/unconnected.*") ""))
+
+              ;; These fail because "subdomain.localhost" does not resolve in
+              ;; the build environment.  Moreover, the hsts-test suite fails on
+              ;; i686-linux because of errors from `session_get_uri' like
+              ;; "Unexpected status 200 OK (expected 301 Moved Permanently)"
+              ;; (see: https://gitlab.gnome.org/GNOME/libsoup/-/issues/239).
+              (substitute* "tests/meson.build"
+                ((".*'name': 'hsts'.*") ""))
+              (substitute* "tests/hsts-db-test.c"
+                ((".*/hsts-db/subdomains.*") "")))))))
     (native-inputs
      (list `(,glib "bin") ;for glib-mkenums
            gobject-introspection
@@ -5099,13 +5100,13 @@ (define-public libsoup-minimal-2
         #~(cons "-Dgtk_doc=false"
                 (delete "-Ddocs=disabled" #$configure-flags)))
        ((#:phases phases)
-        `(modify-phases ,phases
-           (replace 'adjust-tests
-             (lambda _
-               ;; Disable the SSL test, failing since 2.68 and resolved in
-               ;; libsoup 3.
-               (substitute* "tests/meson.build"
-                 (("[ \t]*\\['ssl', true, \\[\\]\\],") ""))))))))
+        #~(modify-phases #$phases
+            (replace 'adjust-tests
+              (lambda _
+                ;; Disable the SSL test, failing since 2.68 and resolved in
+                ;; libsoup 3.
+                (substitute* "tests/meson.build"
+                  (("[ \t]*\\['ssl', true, \\[\\]\\],") ""))))))))
     (native-inputs
      (modify-inputs (package-native-inputs libsoup-minimal)
        (replace "vala" vala-0.52)))))
-- 
2.41.0